# Open-ABM

Open ABM runs on MESA and wraps basic MESA implementations with easy-to-use helper functions. All current models were built by the MESA team. Users are encouraged to explore MESA and its tools after getting started with Open ABM here: https://mesa.readthedocs.io/en/master/tutorials/intro_tutorial.html

To get started, please see our Jupyter notebook in the 'Introductory Walkthrough' folder. Also keep in mind that you may access the source code of any template models under the 'examples' folder. 
